% A program to make fisheries charts based on Bjorndal and Conrad
close all; clear all; format long;
%%
figure; hold on; 
% Simple growth model
% discrete time quadratic
ll = 3.2e6 ; % metric tons carrying capacity
g = .08  ;% growth rate
incr = .001e6;
S = 0:incr:3.2e6;  %stock variable
F = g.*S.*(1-S./ll);  %growth
[nnnnn , n] = size(F);  
plot(S*1.0e-6,F*1.0e-3,'-k')
title('Figure 18.1. Stock-Growth Curve.')
xlabel('Stock (mmt)')
ylabel('Growth (kmt)') 
set(gca,'Xtick',0:.4:3.2);
% msy stock is 1.6 mmt
Fmax = g*ll/2*(1/2);
set(gca,'Ytick',[0:10:60,Fmax/1000,70]);
corner(ll/2*1.0e-6,Fmax/1000);
hold off;
%%
%long run
sinf = .25e6 ;  c = 556380; p = 735; %kinf = 393 ;
%stock, cost and price.
% cost per season vessel and price per ton in NOK.
catconst = c/(p*sinf);  % the constant k catchability
k = catconst;
Fss = g*sinf*(1-sinf/ll);  % open access harvest
Ess = Fss/(catconst*sinf); % open access number of boats
%figure; hold on;
%plot(S*1.0e-6,F*1.0e-3,'-k')
%corner(sinf*1.0e-6,Fss*1.0e-3);
%title('Figure 18.2. Growth and Harvest')
%xlabel('Stock (mmt)')
%ylabel('Growth and Harvest(kmt)') 
%set(gca,'Xtick', [0,.25,.5:.5:3])
%set(gca,'Ytick',[0,10, round2(Fss/1000,1),30:10:70])
%hold off;

%% Derive yield effort 18.2
figure; hold on;
plot(S*1.0e-6,F*1.0e-3,'-k')
%Now create some kES lines
Ess1 = Fmax/k/1.6e6 ;   %max sustainable yield 
Ess2 = .25*Ess;

% coordinates where yield = growth
IEss = find(k*Ess*S > F,1);
xEss = [S(IEss)*1.0e-6,F(IEss)*1.0e-3]; % corner(xEss); 
IEss2 = find(k*Ess2*S > F,1);
xEss2 = [S(IEss2)*1.0e-6,F(IEss2)*1.0e-3];
IEss1 = find(k*Ess1*S > F,1);
xEss1 = [S(IEss1)*1.0e-6,F(IEss1)*1.0e-3];

plot(S*1.0e-6, k*Ess1*S*1.0e-3,'k--');
plot(S*1.0e-6, k*Ess*S*1.0e-3,'k--'); 
plot(S*1.0e-6, k*Ess2*S*1.0e-3,'k--');
lightcorner(S(IEss2)*1.0e-6,F(IEss2)*1.0e-3);
lightcorner(S(IEss)*1.0e-6,F(IEss)*1.0e-3);
lightcorner(S(IEss1)*1.0e-6,F(IEss1)*1.0e-3);
title('Figure 18.2 Harvest for 3 Levels of Effort.')
xlabel('Stock (mmt)')
ylabel('Yield (kmt)') 
text(1.9,74,'\leftarrow E= 13.2');
text(1.1,75,'\leftarrow E = 24.4')
text(2.7,49,'\leftarrow E = 6.1')
set(gca,'Xtick',[0,round2(S(IEss)*1.0e-6,2),round2(S(IEss1)*1.0e-6,2),round2(S(IEss2)*1.0e-6,2),3.2]);
set(gca,'Ytick',[0, round2(F(IEss)*1.0e-3,1),round2(F(IEss2)*1.0e-3,1),round2(F(IEss1)*1.0e-3,1),80]);
axis([0,3.2,0,80]);
hold off;
%%

%% Draw Yield Effort 18.3
figure; hold on; 
%F(S) = kES so E = F/S/k
EY = (F./S)/k;
plot(EY,F*1.0e-3,'k-')
lightcorner(Ess2,F(IEss2)*1.0e-3);
lightcorner(Ess,F(IEss)*1.0e-3);
lightcorner(Ess1,F(IEss1)*1.0e-3);
title('Figure 18.3. The Effort Yield Curve');
set(gca,'Xtick',[0,round2(Ess2,1),round2(Ess1,1), round2(Ess,1)]);
set(gca,'Ytick',[0, round2(F(IEss)*1.0e-3,1),round2(F(IEss2)*1.0e-3,1),round2(F(IEss1)*1.0e-3,1),80]);
xlabel('Boat-years');
ylabel('Harvest (kmt)') 
hold off;
%% Draw Revenue Effort 18.4
figure; hold on; 

plot(EY,p*F*1.0e-6,'k-',EY,c*EY*1.0e-6,'k-')
title('Figure 18.4. The Effort Revenue  and Effort Cost Curves');
set(gca,'Xtick',[0,round2(Ess2,1),round2(Ess1,1), round2(Ess,1)]);
%set(gca,'Ytick',p*1.0e-6*[0,c*Ess2/p,c*Ess1/p,F(IEss),F(IEss2),F(IEss1)]);
tempx =[0,round2(c*Ess2*1.0e-6,1),round2(c*Ess1*1.0e-6,1),round2(p*F(IEss)*1.0e-6,1)...
    ,round2(p*F(IEss2)*1.0e-6,1),round2(F(IEss1)*1.0e-6*p,1)];
set(gca,'Ytick',tempx);
corner(Ess,p*F(IEss)*1.0e-6);
corner(Ess1,p*F(IEss1)*1.0e-6);
corner(Ess2,p*F(IEss2)*1.0e-6);
corner(Ess1,c*Ess1*1.0e-6);
corner(Ess2,c*Ess2*1.0e-6);
xlabel('Boat-years');
ylabel('Millions of NOK')
hold off;
%% Draw Revenue Effort 18.6 (NEW JULY 09)
% What happens when c goes up.
c2 = 5*c;
profit = p*F-c*EY;
profit2 = p*F-c2*EY;
iprofitmax = find(max(profit) == profit);
iprofitmax2 = find(max(profit2) == profit2);
iprofitmin = find(min(profit) == profit);
iprof20 = find(profit2 >= 0,1);

figure;  
subplot(2,1,1); hold on;
axis([0,26,0,50]);
plot(EY,p*F*1.0e-6,'k-',EY,c*EY*1.0e-6,'k-')
plot(EY,c2*EY*1.0e-6,'k--')
%title('Figure 18.4. The Effort Revenue  and Effort Cost Curves');
%set(gca,'Xtick',[0,round2(Ess2,1),round2(Ess1,1), round2(Ess,1)]);
xtickerProf = [0,round2(EY(iprofitmax2),1),round2(EY(iprofitmax),1),...
    round2(EY(iprof20),1), round2(Ess,1)];
set(gca,'Xtick',xtickerProf);
%set(gca,'Ytick',p*1.0e-6*[0,c*Ess2/p,c*Ess1/p,F(IEss),F(IEss2),F(IEss1)]);
%tempx =[0,round2(c*Ess2*1.0e-6,1),round2(c*Ess1*1.0e-6,1),round2(p*F(IEss)*1.0e-6,1)...
%    ,round2(p*F(IEss2)*1.0e-6,1),round2(F(IEss1)*1.0e-6*p,1)];
set(gca,'Ytick',[0,round2(c*EY(iprofitmax)*1.0e-6,1),round2(c2*EY(iprofitmax2)*1.0e-6,1),...
    round2(p*F(iprofitmax2)*1.0e-6,1),round2(p*F(iprofitmax)*1.0e-6,1)]);
ylabel('Millions of NOK')

hold off;

%

% Profits
%figure; hold on; 
subplot(2,1,2); hold on;
axis([0,26,-15,42]);

%title('Figure 18.5.  Profits in Steady State.')
plot(EY, profit*1.0e-6,'k-')
plot(EY, profit2*1.0e-6,'k--');

cornerm15(EY(iprofitmax),profit(iprofitmax)*1.0e-6);
cornerm15(EY(iprofitmax2),profit2(iprofitmax2)*1.0e-6);
plot([0,26],[0,0],'k:')
set(gca,'Xtick',xtickerProf);
%[0,round2(EY(iprofitmax2),1),round2(EY(iprofitmax),1), round2(Ess,1)]);

set(gca,'Ytick',[ -15,0,...
   round2(profit2(iprofitmax2)*1.0e-6,1), round2(profit(iprofitmax)*1.0e-6,1)]); 
%%


%% Figure 19.3  Phase space
Eiso = g*(1-S./ll)/k;  %xdot = zero
isinf = find(S >= sinf,1);
figure; hold on;
plot(S*1.0e-6, Eiso,'-k')
plot([sinf*1.0e-6,sinf*1.0e-6],[0,30],'-k');
title('Figure 19.3. Zero Profit and Zero Growth')
xlabel('Stock (mmt)')
ylabel('Boats') 
set(gca,'Xtick', [0,.25,.5:.5:3])
set(gca,'Ytick',[0:5:20,round2(Eiso(isinf),1),30])
hold off;
%% Figure 19.4  Close up
figure; hold on;
plot(S*1.0e-6, Eiso,'-k')
%plot([sinf*1.0e-6,sinf*1.0e-6],[0,30],'-k');
title('Figure 19.4.  Constant Stock')
xlabel('Stock (mmt)')
ylabel('Boats') 
set(gca,'Xtick', [0,.25,.5:.5:3])

axis([0,1,15,30])
text(.45,24,.5,'\leftarrow');
text(.125,28,'\leftarrow'); 
text(.125,20,'\rightarrow')
text(.5,20,'\rightarrow')
% A Point on Edot = 0
Spoint = .5e6;
iSpoint = find(S >= Spoint,1);
Epoint = Eiso(iSpoint);
disp('Spoint,Epoint');
disp([Spoint,Epoint]); 
Gpoint = F(iSpoint);
kExpoint = k*24*Spoint;
disp('Gpoint,kExpoint');
disp([Gpoint,kExpoint]);
plot(Spoint*1.0e-6,24,'*k');plot(Spoint*1.0e-6,Epoint,'*k');
set(gca,'Ytick',[0:5:20,round2(Epoint,1),24,30])
hold off;
%% Figure 19.5  Close up
figure; hold on;
plot(S*1.0e-6, Eiso,'-k')
plot([sinf*1.0e-6,sinf*1.0e-6],[0,30],'-k');
title('Figure 19.5. Zero Profit and Unchanging Stock')
xlabel('Stock (mmt)')
ylabel('Boats') 
set(gca,'Xtick', [0,.25,.5:.5:3])
set(gca,'Ytick',[0:5:20,round2(Eiso(isinf),1),30])
axis([0,1,15,30])
text(.5,25,'\leftarrow');text(.53,25.2,'\uparrow')
text(.125,28,'\leftarrow'); text(.15,27.5,'\downarrow')
text(.11,19.5,'\downarrow'); text(.125,20,'\rightarrow')
text(.485,20.2,'\uparrow'); text(.5,20,'\rightarrow')
hold off;

%% Figure 19.6  Simulation
nstep = 10000;
ss(1:nstep) = 0; ee(1:nstep) = 0;
ssize=.1;
ss(1) = .75e6; ee(1) = 15;
for i =1:(nstep-1)
    ss(i+1) = ss(i) + (g*ss(i)*(1-ss(i)/ll)-k*ss(i)*ee(i))*ssize;
    ee(i+1) = ee(i) + (2.0e-6*(p*k*ss(i)- c))*ssize;
end
figure;
plot(ss*1.0e-6,ee,'-k')
title('Figure 18.6. Evoloution of the Fishery')
xlabel('Stock (mmt)')
ylabel('Boats') 
set(gca,'Xtick', 0:.25:.75);
set(gca,'Ytick',[0:5:20,round2(Eiso(isinf),1),30:5:50])
%% Figure 19.x  Simulation with NO boats
nstep = 150;
ss(1:nstep) = 0; ee(1:nstep) = 0;
ssize=1;
ss(1) = 1.6e6; ee(1) = 0;
for i =1:(nstep-1)
    ss(i+1) = ss(i) + (g*ss(i)*(1-ss(i)/ll))*ssize;
%    ee(i+1) = ee(i) + (2.0e-6*(p*k*ss(i)- c))*ssize;
end
Numbersforbook= [ss(1),ss(2),ss(3),ss(4),ss(9),ss(40),ss(150)];
changeinnumbers = [ss(2)-ss(1),ss(3)-ss(2),ss(4)-ss(3), ss(10)-ss(9), ss(41)-ss(40), ss(151)-ss(150)];
figure;
plot(1:nstep,ss(1:nstep)*1.0e-6,'-k')
title('Figure 19.6. Evoloution of the Fishery')
xlabel('Stock (mmt)')
ylabel('Boat-years') 
%set(gca,'Xtick', 0:.25:.75);
%set(gca,'Ytick',[0:5:20,round2(Eiso(isinf),1),30:5:50])
%% Figure 19.7  Critical Depensation  NEW JULY 09


figure; hold on; 
offset = 30;
TF = F*1.0e-3-offset;
plot(S*1.0e-6,TF,'-k');
iCD = find(TF >=0,1);
%title('Figure 19.7. Depensation.')
xlabel('Stock (mmt)')
ylabel('Growth (kmt)') 
set(gca,'Xtick',[0,.25,round2( S(iCD)*1.0e-6,2),1:.5:3.5]);
set(gca,'Ytick',[-offset,0:10:50]);
plot([S(iCD)*1.0e-6,S(iCD)*1.0e-6],[-offset,0],':k');
plot([0,S(iCD)*1.0e-6,],[0,0],':k');
plot([0,2],[0,0],'k-')
plot([.25,.25],[-15,50],'k:');
axis([0,2,-15,50]);
text(.28,40,'Zero Profit Stock');
text(1,18,'Growth Function');

hold off; 


%%
Fp = diff(F)./incr;
Fp(n)=Fp(n-1);
tab191 = [S.*1e-6 ; F.*1e-3 ; Fp]' ;
format short;
disp('    Stock     Growth    Growth Increment');
disp(tab191(101:100:end,:));

r = .05 ; % interest rate
ifr = find(r >= Fp ,1);
sfp = S(ifr);
%% One more fish exercise
% we start at at steady state
% Eiso is the steady state E associated with a S.
% decreasing h by .05mmt
Dcost = p - c/k./S ;  
% results in stock going up by 1 + f'
Sincrease = 1 + Fp;
Oprofit2 = F .*(p - c/k./S);  %old harvest is growth F
Newh = F + Sincrease;
NewS = S + Sincrease;
Newprofit2 = Newh .*(p - c/k./NewS);
tab192 = [S*1e-6 ; Dcost*1e-3; 1e-3*(Newprofit2-Oprofit2)/(1+r)]';
disp('  Stock      First Period         Second Period')
disp('             Change in Profit     Change in Profit')
disp('    mmt          th NOK               th NOK')

center = find( Dcost*1e-3 >= 1e-3*(Newprofit2-Oprofit2)/(1+r),1);
disp(tab192(center-3:center+2,:));

% one could now check and see that if costs were zero we got the right
% answer, or one could use the calculus for the foc.


%steady state stock
%C = c/catconst./S ;  %first element would be infinity!  watch out for the 2:n
%Cp = diff(C)./incr;
%Cp(n)=Cp(n-1);
%%
Prof = p*catconst.*S -c;


